"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.filterLogStreamForPort = exports.isFailureToSetupListener = exports.parseAnyLogEntry = exports.createLogEntryIterator = void 0;
const stream_1 = require("stream");
const readline_1 = require("readline");
async function* createLogEntryIterator(stdout) {
    for await (const line of (0, readline_1.createInterface)({ input: stdout })) {
        if (!line.trim()) {
            continue;
        }
        try {
            const logEntry = parseAnyLogEntry(line);
            yield logEntry;
        }
        catch (error) {
            break;
        }
    }
}
exports.createLogEntryIterator = createLogEntryIterator;
function parseOldLogEntry(line) {
    const re = /^(?<timestamp>\S*) *(?<severity>\S*) *(?<component>\S*) *\[(?<context>[^\]]+)\]\s*(?<message>.*)$/;
    const match = re.exec(line.trim());
    if (!match) {
        throw new Error(`Could not parse line ${JSON.stringify(line)}`);
    }
    return match.groups;
}
function parseAnyLogEntry(line) {
    var _a;
    try {
        const newFormat = JSON.parse(line);
        return {
            id: newFormat.id,
            timestamp: (_a = newFormat.t) === null || _a === void 0 ? void 0 : _a.$date,
            severity: newFormat.s,
            component: newFormat.c,
            context: newFormat.ctx,
            message: newFormat.msg,
            attr: newFormat.attr,
        };
    }
    catch (_b) {
        return parseOldLogEntry(line);
    }
}
exports.parseAnyLogEntry = parseAnyLogEntry;
function isFailureToSetupListener(entry) {
    return (entry.id === 22856 ||
        entry.message.includes('Failed to set up listener'));
}
exports.isFailureToSetupListener = isFailureToSetupListener;
function getPortFromLogEntry(logEntry) {
    var _a, _b;
    let match;
    if (logEntry.id === 23016) {
        return logEntry.attr.port;
    }
    if (logEntry.id === undefined &&
        (match = /^waiting for connections on port (?<port>\d+)$/i.exec(logEntry.message))) {
        return +((_b = (_a = match.groups) === null || _a === void 0 ? void 0 : _a.port) !== null && _b !== void 0 ? _b : '0');
    }
    if (isFailureToSetupListener(logEntry)) {
        throw new Error(`Failed to setup listener (${logEntry.message} ${JSON.stringify(logEntry.attr)})`);
    }
    return -1;
}
async function filterLogStreamForPort(input) {
    let port = -1;
    const inputDuplicate = input.pipe(new stream_1.PassThrough({ objectMode: true }));
    try {
        for await (const logEntry of inputDuplicate) {
            if (logEntry.component !== 'NETWORK' ||
                !['initandlisten', 'listener'].includes(logEntry.context)) {
                continue;
            }
            port = getPortFromLogEntry(logEntry);
            if (port !== -1) {
                break;
            }
        }
    }
    finally {
        input.unpipe(inputDuplicate);
    }
    return { port };
}
exports.filterLogStreamForPort = filterLogStreamForPort;
//# sourceMappingURL=mongologreader.js.map